<?php

/**
 * @file
 * Contains \Drupal\drd\Command\BaseCore.
 */

namespace Drupal\drd\Command;

use Drupal\Console\Core\Style\DrupalStyle;
use Drupal\drd\Plugin\Action\BaseEntityRemote;
use Symfony\Component\Console\Input\InputInterface;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Output\OutputInterface;

/**
 * Class BaseCore.
 *
 * @package Drupal\drd
 */
abstract class BaseCore extends Base {

  /**
   * {@inheritdoc}
   */
  protected function configure() {
    parent::configure();
    $this
      ->addOption(
        'core-id',
        NULL,
        InputOption::VALUE_OPTIONAL,
        $this->trans('commands.drd.actions.remote.arguments.core-id')
      );
  }

  /**
   * {@inheritdoc}
   */
  protected function execute(InputInterface $input, OutputInterface $output) {
    $action = parent::execute($input, $output);
    $io = new DrupalStyle($input, $output);

    if (empty($action) || !($action instanceof BaseEntityRemote)) {
      $io->error('No valid remote action!');
      return;
    }

    $core_id = $input->getOption('core-id');
    if ($core_id) {
      $cores = [
        \Drupal::entityTypeManager()
          ->getStorage('drd_core')
          ->load($core_id)
      ];
    }
    else {
      $cores = \Drupal::entityTypeManager()
        ->getStorage('drd_core')
        ->loadByProperties([
          'status' => 1,
        ]);
    }
    $io->info('Executing ' . $action->getPluginDefinition()['label']);
    foreach ($cores as $core) {
      /** @var \Drupal\drd\Entity\CoreInterface Core $core */
      $io->info('- on ' . $core->getName());
      if ($action->executeAction($core)) {
        $response = $action->getResponse();
        if (is_array($response) && !empty($response['output'])) {
          $io->info('  ' . $response['output']);
        }
        $io->success('  ok!');
      }
      else {
        $io->error('  failure!');
      }
    }

    $io->info('Completed!');
  }

}
