<?php

namespace Drupal\drd;

/**
 * Class DnsLookup.
 *
 * @package Drupal\drd
 */
class DnsLookup {

  public function lookup($name, &$ipv4, &$ipv6) {
    foreach (dns_get_record($name, DNS_ALL) as $record) {
      switch ($record['type']) {
        case 'A':
          $ipv4[] = ip2long($record['ip']);
          break;

        case 'A6':
          if (function_exists('gmp_strval')) {
            $ipv6[] = self::ip2long6($record['ip']);
          }
          break;
      }
    }
  }

  /**
   * Convert IPv6 address to long
   * Requires PHP GMP library
   * @Credit f.wiessner@smart-weblications.net
   * http://www.php.net/manual/en/function.ip2long.php#94477
   */
  public function ip2long6($ipv6) {
    if (!function_exists('gmp_strval')) {
      return 0;
    }
    $ipv6long = '';
    $ip_n = inet_pton($ipv6);
    $bits = 15; // 16 x 8 bit = 128bit
    while ($bits >= 0) {
      $bin = sprintf("%08b",(ord($ip_n[$bits])));
      $ipv6long = $bin.$ipv6long;
      $bits--;
    }
    return gmp_strval(gmp_init($ipv6long,2),10);
  }

}
