<?php

/**
 * @file
 * Contains \Drupal\drd\Entity\Form\CoreDelete.
 */

namespace Drupal\drd\Entity\Form;

use Drupal\Core\Entity\ContentEntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\drd\Entity\Core;
use Drupal\drd\Entity\Domain;

/**
 * Provides a form for deleting Core entities.
 *
 * @ingroup drd
 */
class CoreDelete extends ContentEntityConfirmFormBase {
  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to delete core %name and all of its domains?', ['%name' => $this->entity->label()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('entity.drd_core.collection');
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Delete');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    /** @var Core $core */
    $core = $this->entity;

    // Delete all domains first
    foreach ($core->getDomains() as $domain) {
      /** @var Domain $domain */
      $domain->delete();
    }

    // Now delete the core itself
    $core->delete();

    drupal_set_message(
      $this->t('content @type: deleted @label.',
        [
          '@type' => $this->entity->bundle(),
          '@label' => $this->entity->label()
        ]
        )
    );

    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
