<?php

/**
 * @file
 * Contains \Drupal\drd\Entity\Form\DomainReset.
 */

namespace Drupal\drd\Entity\Form;

use Drupal\Core\Entity\ContentEntityConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\drd\Entity\Domain;

/**
 * Provides a form for resetting domain entities.
 *
 * @ingroup drd
 */
class DomainReset extends ContentEntityConfirmFormBase {
  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to reset domain %name so that you have to re-authenticate this DRD instance?', ['%name' => $this->entity->label()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    /** @var Domain $domain */
    $domain = $this->entity;
    return new Url('entity.drd_core.canonical', ['drd_core' => $domain->getCore()->id()]);
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {
    return $this->t('Reset');
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    /** @var Domain $domain */
    $domain = $this->entity;
    $domain->setName(NULL);
    $domain->save();
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
