<?php

/**
 * @file
 * Contains \Drupal\drd\Entity\ListBuilder\Domain.
 */

namespace Drupal\drd\Entity\ListBuilder;

use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Entity\EntityListBuilder;
use Drupal\Core\Routing\LinkGeneratorTrait;
use Drupal\Core\Url;

/**
 * Defines a class to build a listing of Domain entities.
 *
 * @ingroup drd
 */
class Domain extends EntityListBuilder {
  use LinkGeneratorTrait;
  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['id'] = $this->t('Domain ID');
    $header['name'] = $this->t('Name');
    $header['config'] = $this->t('Config Link');
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $domain) {
    /* @var $domain \Drupal\drd\Entity\Domain */
    $row['id'] = $domain->id();
    $row['name'] = $this->l(
      $domain->label(),
      new Url(
        'entity.drd_domain.edit_form', [
          'drd_domain' => $domain->id(),
        ]
      )
    );
    if ($domain->get('installed')->value) {
      $row['config'] = $domain->getRemoteSetupLink($this->t('Configure'));
    }
    else {
      $row['config'] = '';
    }
    return $row + parent::buildRow($domain);
  }

}
