<?php

/**
 * @file
 * Contains \Drupal\drd\Entity\MajorInterface.
 */

namespace Drupal\drd\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Major Version entities.
 *
 * @ingroup drd
 */
interface MajorInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {
  // Add get/set methods for your configuration properties here.

  /**
   * Gets the Major Version name.
   *
   * @return string
   *   Name of the Major Version.
   */
  public function getName();

  /**
   * Sets the Major Version name.
   *
   * @param string $name
   *   The Major Version name.
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setName($name);

  /**
   * Gets the Major Version coreversion.
   *
   * @return int
   *   Core version of the Major Version.
   */
  public function getCoreVersion();

  /**
   * Sets the Major Version coreversion.
   *
   * @param int $coreversion
   *   The Major Version core version.
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setCoreVersion($coreversion);

  /**
   * Gets the Major Version majorversion.
   *
   * @return int
   *   Major version of the Major Version.
   */
  public function getMajorVersion();

  /**
   * Sets the Major Version major version.
   *
   * @param int $majorversion
   *   The Major Version major version.
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setMajorVersion($majorversion);

  /**
   * Gets the Major Version project.
   *
   * @return Project
   *   Project of the Major Version.
   */
  public function getProject();

  /**
   * Sets the Major Version project.
   *
   * @param Project $project
   *   The Major Version project.
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setProject($project);

  /**
   * Gets the Major Version parent project.
   *
   * @return Project
   *   Parent project of the Major Version.
   */
  public function getParentProject();

  /**
   * Sets the Major Version parent project.
   *
   * @param Project $project
   *   The Major Version parent project.
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setParentProject($project);

  /**
   * Gets the Major Version recommended release.
   *
   * @return Release
   *   Recommended release of the Major Version.
   */
  public function getRecommendedRelease();

  /**
   * Sets the Major Version recommended release.
   *
   * @param Release $release
   *   The Major Version recommended release.
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setRecommendedRelease($release);

  /**
   * Gets the Major Version creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Major Version.
   */
  public function getCreatedTime();

  /**
   * Sets the Major Version creation timestamp.
   *
   * @param int $timestamp
   *   The Major Version creation timestamp.
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Major Version published status indicator.
   *
   * Unpublished Major Version are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Major Version is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Major Version.
   *
   * @param bool $published
   *   TRUE to set this Major Version to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setPublished($published);

  /**
   * Returns the Major Version hidden status indicator.
   *
   * Hidden Major Version will not be checked for update status.
   *
   * @return bool
   *   TRUE if the Major Version is hidden.
   */
  public function isHidden();

  /**
   * Sets the hidden status of a Major Version.
   *
   * @param bool $hidden
   *   TRUE to set this Major Version to hidden, FALSE otherwise (default).
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setHidden($hidden);

  /**
   * Returns the Major Version supported status indicator.
   *
   * Unsupported Major Version will raise warnings.
   *
   * @return bool
   *   TRUE if the Major Version is supported.
   */
  public function isSupported();

  /**
   * Sets the supported status of a Major Version.
   *
   * @param bool $supported
   *   TRUE to set this Major Version to supported (default), FALSE otherwise.
   *
   * @return \Drupal\drd\Entity\MajorInterface
   *   The called Major Version entity.
   */
  public function setSupported($supported);

  /**
   * @param string $type
   * @param string $name
   * @param string $version
   * @return \Drupal\drd\Entity\ReleaseInterface
   */
  public static function findOrCreate($type, $name, $version);

}
