<?php

/**
 * @file
 * Contains \Drupal\drd\Entity\ProjectInterface.
 */

namespace Drupal\drd\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Project entities.
 *
 * @ingroup drd
 */
interface ProjectInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {
  // Add get/set methods for your configuration properties here.

  /**
   * Gets the Project label.
   *
   * @return string
   *   Label of the Project.
   */
  public function getLabel();

  /**
   * Sets the Project label.
   *
   * @param string $label
   *   The Project label.
   *
   * @return \Drupal\drd\Entity\ProjectInterface
   *   The called Project entity.
   */
  public function setLabel($label);

  /**
   * Gets the Project name.
   *
   * @return string
   *   Name of the Project.
   */
  public function getName();

  /**
   * Sets the Project name.
   *
   * @param string $name
   *   The Project name.
   *
   * @return \Drupal\drd\Entity\ProjectInterface
   *   The called Project entity.
   */
  public function setName($name);

  /**
   * Gets the Project type.
   *
   * @return string
   *   Name of the Project.
   */
  public function getType();

  /**
   * Sets the Project type.
   *
   * @param string $type
   *   The Project type.
   *
   * @return \Drupal\drd\Entity\ProjectInterface
   *   The called Project entity.
   */
  public function setType($type);

  /**
   * Gets the Project creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Project.
   */
  public function getCreatedTime();

  /**
   * Sets the Project creation timestamp.
   *
   * @param int $timestamp
   *   The Project creation timestamp.
   *
   * @return \Drupal\drd\Entity\ProjectInterface
   *   The called Project entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Project published status indicator.
   *
   * Unpublished Project are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Project is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Project.
   *
   * @param bool $published
   *   TRUE to set this Project to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\drd\Entity\ProjectInterface
   *   The called Project entity.
   */
  public function setPublished($published);

  /**
   * @return \Drupal\Core\Url
   */
  public function getProjectLink();

  /**
   * @param string $type
   * @param string $name
   * @return \Drupal\drd\Entity\ProjectInterface
   */
  public static function findOrCreate($type, $name);

}
