<?php

/**
 * @file
 * Contains \Drupal\drd\Plugin\Action\BaseEntityRemote.
 */

namespace Drupal\drd\Plugin\Action;

use Drupal\drd\HttpRequest;
use Drupal\drd\Entity\DomainInterface;

/**
 * Base class for DRD Remote Action plugins.
 */
abstract class BaseEntityRemote extends BaseEntity {

  protected $response = FALSE;

  /**
   * @param string $id
   * @param \Drupal\drd\Entity\BaseInterface $remote
   *
   * @return array|bool
   */
  public static function response($id, $remote, $arguments = []) {
    /** @var BaseEntityInterface $action */
    $action = self::instance($id);
    if ($action) {
      foreach ($arguments as $key => $value) {
        $action->setActionArgument($key, $value);
      }
      return $action->executeAction($remote);
    }
    return FALSE;
  }

  /**
   * Default remote action which can be overwritten by implementations.
   *
   * @param DomainInterface $domain
   * @return array|bool
   */
  public function executeAction($domain) {
    $this->response = FALSE;
    if (!$this->access($domain)) {
      return FALSE;
    }
    $this->remoteRequest();
    return $this->getResponse();
  }

  public function getResponse() {
    return $this->response;
  }

  protected function remoteRequest() {
    /** @var DomainInterface $domain */
    $domain = $this->drdEntity;
    $class = explode('\\', get_class($this));

    // Add authentication
    $args = [
      'auth' => $domain->get('auth')->value,
      'authsetting' => $domain->getAuthSetting(),
      'action' => array_pop($class),
    ] + $this->arguments;

    // Encrypt the arguments
    $method = $domain->get('crypt')->value;
    if (empty($method)) {
      return;
    }
    $crypt = \Drupal\drd\Crypt\Base::getInstance(
      $method,
      $domain->getCryptSetting()
    );

    $body = base64_encode(serialize([
      'uuid' => $domain->uuid(),
      'args' => $crypt->encrypt($args),
      'iv' => $crypt->getIV(),
    ]));

    /** @var HttpRequest $request */
    $request = \Drupal::service('drd.http_request');
    $request->setDomain($domain)
      ->setQuery('drd-agent')
      ->setOption('body', $body)
      ->request();
    if (!$request->isRemoteDrd()) {
      return;
    }
    try {
      $this->response = $crypt->decrypt($request->getResponse(), $crypt->getIV());
    } catch (\Exception $ex) {
      return;
    }

    if (!empty($this->response['messages'])) {
      $domain->cacheRemoteMessages($this->response['messages']);
    }
    unset($this->response['messages']);

    if ($followup = $this->getFollowUpAction()) {
      \Drupal::service('queue.drd')->createItem(Base::instance($followup), $domain);
    }
  }

}
