<?php

namespace Drupal\drd\Plugin\Block;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Block\Annotation\Block;
use Drupal\Core\Url;

/**
 * Provides a 'WidgetProjects' block.
 *
 * @Block(
 *  id = "drd_projects",
 *  admin_label = @Translation("DRD Projects"),
 *  weight = -4,
 *  tags = {"drd_widget"},
 * )
 */
class WidgetProjects extends Base {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];

    $query = \Drupal::database()->select('drd_project', 'p');
    $query->join('drd_major', 'm', 'm.project = p.id');
    $projects = $query
      ->condition('m.hidden', 0)
      ->isNull('m.parentproject')
      ->countQuery()
      ->execute()
      ->fetchField();
    $query = \Drupal::database()->select('drd_release', 'r');
    $query->join('drd_major', 'm', 'm.id = r.major');
    $releases = $query
      ->condition('m.hidden', 0)
      ->isNull('m.parentproject')
      ->countQuery()
      ->execute()
      ->fetchField();
    $query = \Drupal::database()->select('drd_release', 'r');
    $query->join('drd_major', 'm', 'm.id = r.major');
    $critical = $query
      ->condition('r.updatestatus', [
        UPDATE_NOT_SECURE,
        UPDATE_NOT_SUPPORTED,
        UPDATE_REVOKED
      ], 'IN')
      ->condition('m.hidden', 0)
      ->isNull('m.parentproject')
      ->countQuery()
      ->execute()
      ->fetchField();
    $query = \Drupal::database()->select('drd_release', 'r');
    $query->join('drd_major', 'm', 'm.id = r.major');
    $recommended = $query
      ->condition('r.updatestatus', [
        UPDATE_FETCH_PENDING,
        UPDATE_UNKNOWN,
        UPDATE_NOT_FETCHED,
        UPDATE_NOT_CHECKED,
        UPDATE_NOT_CURRENT
      ], 'IN')
      ->condition('m.hidden', 0)
      ->isNull('m.parentproject')
      ->countQuery()
      ->execute()
      ->fetchField();

    if ($projects == 0) {
      $message = $this->t('You currently have no projects in DRD!');
    }
    else {
      $message = $this->t('<p class="message">%count1 projects / %count2 releases</p>', [
        '%count1' => $projects,
        '%count2' => $releases
      ]);
      $message .= $this->t('<p>Get all the details in your <a href="@list">projects list</a>.', ['@list' => (new Url('entity.drd_project.collection'))->toString()]);
    }
    $message .= t('<p>Projects will be automatically recognised from your domains when you execute the <strong>Collect used projects</strong> action in the <a href="@list">domain list</a>.</p>',
      ['@list' => (new Url('entity.drd_domain.collection'))->toString()]);

    if ($critical > 0) {
      $message .= $this->t('<p class="message critical">%count critical updates available</p>', [
        '%count' => $critical
      ]);
    }
    if ($recommended > 0) {
      $message .= $this->t('<p class="message recommended">Other updates: %count</p>', [
        '%count' => $recommended
      ]);
    }

    $build['drd_projects']['#markup'] = $message;

    return $build;
  }

}
